manoby: Interactive panel MANOVA classic, non parametric and bayesian

Description Usage Arguments Value Examples

View source: R/manoby.R

Description

Interactive panel to visualize and develop one-way multivariate analysis of variance models, from the classical, non-parametric and Bayesian approach.

Usage

1
manoby(dataset = FALSE)

Arguments

dataset

Data set

Value

A shiny panel with the multivariate analyze of variance, PERMANOVA and Bayesian analyzes of variance, based on selection the dependents variables and independent variable of the data set provided, presents decision diagram that suggets correct method use.

Examples

1
2
3
library(MANOVA.RM)
data(EEGwide)
manoby(EEGwide)

MapeBay documentation built on Nov. 15, 2021, 9:06 a.m.