Description Usage Arguments Value Examples
Interactive panel to visualize and develop one-way multivariate analysis of variance models, from the classical, non-parametric and Bayesian approach.
1 |
dataset |
Data set |
A shiny panel with the multivariate analyze of variance, PERMANOVA and Bayesian analyzes of variance, based on selection the dependents variables and independent variable of the data set provided, presents decision diagram that suggets correct method use.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.